==> plantuml-libs-6.0.0.tgz: package/distribution/aws-q3-2021/Architecture/Database/AmazonDocumentDb.md <==
# AmazonDocumentDb


```text
aws-q3-2021/Architecture/Database/AmazonDocumentDb
```

```text
include('aws-q3-2021/Architecture/Database/AmazonDocumentDb')
```



| Illustration | AmazonDocumentDb | AmazonDocumentDbCard | AmazonDocumentDbGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Architecture/Database/AmazonDocumentDb.png) | ![illustration for AmazonDocumentDb](../../../aws-q3-2021/Architecture/Database/AmazonDocumentDb.Local.png) | ![illustration for AmazonDocumentDbCard](../../../aws-q3-2021/Architecture/Database/AmazonDocumentDbCard.Local.png) | ![illustration for AmazonDocumentDbGroup](../../../aws-q3-2021/Architecture/Database/AmazonDocumentDbGroup.Local.png) |




## AmazonDocumentDb

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonDocumentDb
include('aws-q3-2021/Architecture/Database/AmazonDocumentDb')

' renders the element
AmazonDocumentDb('AmazonDocumentDb', 'Amazon Document Db', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonDocumentDb
include('aws-q3-2021/Architecture/Database/AmazonDocumentDb')

' renders the element
AmazonDocumentDb('AmazonDocumentDb', 'Amazon Document Db', 'an optional tech label')
@enduml
```

## AmazonDocumentDbCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonDocumentDbCard
include('aws-q3-2021/Architecture/Database/AmazonDocumentDb')

' renders the element
AmazonDocumentDbCard('AmazonDocumentDbCard', 'Amazon Document Db Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonDocumentDbCard
include('aws-q3-2021/Architecture/Database/AmazonDocumentDb')

' renders the element
AmazonDocumentDbCard('AmazonDocumentDbCard', 'Amazon Document Db Card', 'an optional description')
@enduml
```

## AmazonDocumentDbGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonDocumentDbGroup
include('aws-q3-2021/Architecture/Database/AmazonDocumentDb')

' renders the element
AmazonDocumentDbGroup('AmazonDocumentDbGroup', 'Amazon Document Db Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonDocumentDbGroup
include('aws-q3-2021/Architecture/Database/AmazonDocumentDb')

' renders the element
AmazonDocumentDbGroup('AmazonDocumentDbGroup', 'Amazon Document Db Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-q3-2021/Architecture/Database/AmazonDocumentDb.md <==
# AmazonDocumentDb


```text
aws-q3-2021/Architecture/Database/AmazonDocumentDb
```

```text
include('aws-q3-2021/Architecture/Database/AmazonDocumentDb')
```



| Illustration | AmazonDocumentDb | AmazonDocumentDbCard | AmazonDocumentDbGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Architecture/Database/AmazonDocumentDb.png) | ![illustration for AmazonDocumentDb](../../../aws-q3-2021/Architecture/Database/AmazonDocumentDb.Local.png) | ![illustration for AmazonDocumentDbCard](../../../aws-q3-2021/Architecture/Database/AmazonDocumentDbCard.Local.png) | ![illustration for AmazonDocumentDbGroup](../../../aws-q3-2021/Architecture/Database/AmazonDocumentDbGroup.Local.png) |




## AmazonDocumentDb

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonDocumentDb
include('aws-q3-2021/Architecture/Database/AmazonDocumentDb')

' renders the element
AmazonDocumentDb('AmazonDocumentDb', 'Amazon Document Db', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonDocumentDb
include('aws-q3-2021/Architecture/Database/AmazonDocumentDb')

' renders the element
AmazonDocumentDb('AmazonDocumentDb', 'Amazon Document Db', 'an optional tech label')
@enduml
```

## AmazonDocumentDbCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonDocumentDbCard
include('aws-q3-2021/Architecture/Database/AmazonDocumentDb')

' renders the element
AmazonDocumentDbCard('AmazonDocumentDbCard', 'Amazon Document Db Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonDocumentDbCard
include('aws-q3-2021/Architecture/Database/AmazonDocumentDb')

' renders the element
AmazonDocumentDbCard('AmazonDocumentDbCard', 'Amazon Document Db Card', 'an optional description')
@enduml
```

## AmazonDocumentDbGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonDocumentDbGroup
include('aws-q3-2021/Architecture/Database/AmazonDocumentDb')

' renders the element
AmazonDocumentDbGroup('AmazonDocumentDbGroup', 'Amazon Document Db Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonDocumentDbGroup
include('aws-q3-2021/Architecture/Database/AmazonDocumentDb')

' renders the element
AmazonDocumentDbGroup('AmazonDocumentDbGroup', 'Amazon Document Db Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
